@@ -155,6 +155,8 @@ static void multi_win_destructor(MultiWin *win, gboolean destroy_widgets);
 
 static void multi_win_set_icon_title(MultiWin *win, const char *title);
 
+static void multi_win_close_tab_clicked(GtkWidget *widget, MultiTab *tab);
+
 static void multi_win_restore_size(MultiWin *win)
 {
     MultiTab *tab = win->current_tab;
@@ -1069,7 +1071,7 @@ static gboolean tab_clicked_handler(GtkWidget *widget,
             switch (tab->middle_click_action)
             {
                 case 1:
-                    multi_tab_delete(tab);
+                    multi_win_close_tab_clicked(NULL, tab);
                     break;
                 case 2:
                     gtk_clipboard_request_text(
@@ -1176,6 +1178,7 @@ MultiWin *multi_win_new_for_tab(const char *display_name, int x, int y,
     const char *title_template = win->title_template;
     gboolean show_menubar = win->show_menu_bar;
 
+    g_debug("Creating new window for tab with tab_pos %d", win->tab_pos);
     gtk_window_get_size(gwin, &w, &h);
     multi_win_get_disable_menu_shortcuts(tab->user_data,
             &disable_menu_shortcuts, &disable_tab_shortcuts);
@@ -1196,7 +1199,12 @@ MultiWin *multi_win_new_for_tab(const char *display_name, int x, int y,
 
 static void multi_win_close_tab_clicked(GtkWidget *widget, MultiTab *tab)
 {
-    multi_tab_delete(tab);
+    if (!multi_win_delete_handler ||
+            !multi_win_delete_handler(tab->parent->gtkwin, NULL,
+                    tab->user_data))
+    {
+        multi_tab_delete(tab);
+    }
 }
 
 MultiWin *multi_win_clone(MultiWin *old,
@@ -1241,7 +1249,7 @@ static void multi_win_detach_tab_action(MultiWin * win)
 
 static void multi_win_close_tab_action(MultiWin * win)
 {
-    multi_tab_delete(win->current_tab);
+    multi_win_close_tab_clicked(NULL, win->current_tab);
 }
 
 static void multi_win_close_other_tabs_action(MultiWin * win)
@@ -1894,6 +1902,15 @@ MultiWin *multi_win_new_blank(const char *display_name, Options *shortcuts,
         g_object_set(notebook, "tab-vborder", 0, NULL);
     }
 #endif
+    if (tab_pos == -1)
+    {
+        gtk_notebook_set_show_tabs(notebook, always_show_tabs);
+        gtk_notebook_set_show_border(notebook, always_show_tabs);
+    }
+    else
+    {
+        gtk_notebook_set_tab_pos(notebook, tab_pos);
+    }
     gtk_notebook_popup_disable(notebook);
     if (always_show_tabs)
     {
@@ -1953,17 +1970,6 @@ MultiWin *multi_win_new_full(const char *display_name, Options *shortcuts,
     for (n = 0; n < numtabs; ++n)
         multi_tab_new(win, user_data_template);
 
-    if (tab_pos == -1)
-    {
-        gtk_notebook_set_show_tabs(GTK_NOTEBOOK(win->notebook),
-                always_show_tabs);
-        gtk_notebook_set_show_border(GTK_NOTEBOOK(win->notebook),
-                always_show_tabs);
-    }
-    else
-    {
-        gtk_notebook_set_tab_pos(GTK_NOTEBOOK(win->notebook), tab_pos);
-    }
     multi_win_shade_menus_for_tabs(win);
 
     if (geom)
